==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/oc.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitat",
    "Personal activity feed for %s" : "Flux d'activitat personal de %s",
    "Your feed URL is invalid" : "Vòstra adreça de flux es pas valida",
    "Your settings have been updated." : "Vòstres paramètres son estats meses a jorn.",
    "Mail" : "Mail",
    "Stream" : "Flux",
    "Activities" : "Activitat",
    "Error loading activities" : "Error al cargament de l'activitat",
    "No activities" : "Pas cap d'activitat",
    "This stream will show events like additions, changes & shares" : "Aqueste flux fa veire los eveniments tal coma las addicions, las modificacions e los partiments",
    "There are no events for this filter" : "I a pas cap d'eveniment per aqueste filtre",
    "Activity notification" : "Notificacion d'activitat",
    "All Activities" : "Totas activitats",
    "Activities by you" : "Vòstras activitats",
    "Activities by others" : "L'activitat dels autres",
    "\"remote user\"" : "\"utilizaire distant\"",
    "in %s" : "dins %s",
    "%s and %s" : "%s e %s",
    ", " : ", ",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s e <strong %s>%n mai</strong>","%s e <strong %s>%n mai</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s e %n mai","%s e %n mai"],
    "Hello %s," : "Bonjorn %s,",
    "You are receiving this email because the following things happened at %s" : "Recebretz aqueste corrièl perque los eveniments seguents se son debanats a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n mai","* e %n mai"],
    "Notifications" : "Notificacions",
    "List your own actions in the stream" : "Far la lista de mas propres actions dins lo flux",
    "Notify about your own actions via email" : "M'informar de mes pròprias accions per corrièl",
    "You need to set up your email address before you can receive notification emails." : "Es necessari de configurar una adreça corrièl abans de poder recebre las notificacions per corrièl.",
    "Send emails:" : "Mandar de corrièls :",
    "Hourly" : "A cada ora",
    "Daily" : "A cada jorn",
    "Weekly" : "A cada setmana",
    "Activity feed" : "Flux d'activitat",
    "Enable RSS feed" : "Activar los fluxes RSS",
    "No activity yet" : "Pas d'activitat pel moment",
    "No more events to load" : "Pas cap d'eveniment mai a cargar",
    "Files" : "Fichièrs",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s e <strong class=\"has-tooltip\" title=\"%s\">%n mai</strong>","%s e <strong class=\"has-tooltip\" title=\"%s\">%n mai</strong>"]
},
"nplurals=2; plural=(n > 1);");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/oc.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Activitat",
    "Personal activity feed for %s" : "Flux d'activitat personal de %s",
    "Your feed URL is invalid" : "Vòstra adreça de flux es pas valida",
    "Your settings have been updated." : "Vòstres paramètres son estats meses a jorn.",
    "Mail" : "Mail",
    "Stream" : "Flux",
    "Activities" : "Activitat",
    "Error loading activities" : "Error al cargament de l'activitat",
    "No activities" : "Pas cap d'activitat",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Aqueste flux fa veire los eveniments tal coma las addicions, las modificacions e los partiments",
    "There are no events for this filter" : "I a pas cap d'eveniment per aqueste filtre",
    "Today" : "Uèi",
    "Yesterday" : "Ièr",
    "\"remote user\"" : "\"utilizaire distant\"",
    "Activity notification" : "Notificacion d'activitat",
    "All Activities" : "Totas activitats",
    "Activities by you" : "Vòstras activitats",
    "Activities by others" : "L'activitat dels autres",
    "%s and %s" : "%s e %s",
    "Hello %s," : "Bonjorn %s,",
    "You are receiving this email because the following things happened at %s" : "Recebretz aqueste corrièl perque los eveniments seguents se son debanats a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n mai","* e %n mai"],
    "List your own actions in the stream" : "Far la lista de mas propres actions dins lo flux",
    "Notify about your own actions via email" : "M'informar de mes pròprias accions per corrièl",
    "You need to set up your email address before you can receive notification emails." : "Es necessari de configurar una adreça corrièl abans de poder recebre las notificacions per corrièl.",
    "Send emails:" : "Mandar de corrièls :",
    "Hourly" : "A cada ora",
    "Daily" : "A cada jorn",
    "Weekly" : "A cada setmana",
    "Activity feed" : "Flux d'activitat",
    "Enable RSS feed" : "Activar los fluxes RSS",
    "No activity yet" : "Pas d'activitat pel moment",
    "No more events to load" : "Pas cap d'eveniment mai a cargar",
    "Files" : "Fichièrs"
},
"nplurals=2; plural=(n > 1);");
